@@ -48,7 +48,7 @@ from ufoLib2.objects.info import (
 )
 
 # isort: off
-cattr = pytest.importorskip("cattr")
+cattrs = pytest.importorskip("cattrs")
 from ufoLib2.converters import register_hooks, structure, unstructure  # noqa: E402
 
 
@@ -471,7 +471,12 @@ from ufoLib2.converters import register_hooks, structure, unstructure  # noqa: E
         ),
         (
             Font(
-                layers=[Layer(glyphs=[Glyph("a")])],
+                layers=[
+                    Layer(
+                        glyphs=[Glyph("a", tempLib={"foo": "bar"})],
+                        tempLib={"a": 123},
+                    )
+                ],
                 info=Info(familyName="Test"),
                 features="languagesystem DFLT dflt;",
                 groups={"LOWERCASE": ["a"]},
@@ -479,12 +484,14 @@ from ufoLib2.converters import register_hooks, structure, unstructure  # noqa: E
                 lib={"foo": "bar"},
                 data={"baz": b"\0"},
                 images={"foobarbaz": b"\0"},
+                tempLib={"foofoo": "barbar"},
             ),
             {
                 "layers": [
                     {
                         "name": "public.default",
-                        "glyphs": {"a": {}},
+                        "glyphs": {"a": {"tempLib": {"foo": "bar"}}},
+                        "tempLib": {"a": 123},
                     }
                 ],
                 "info": {"familyName": "Test"},
@@ -494,6 +501,7 @@ from ufoLib2.converters import register_hooks, structure, unstructure  # noqa: E
                 "lib": {"foo": "bar"},
                 "data": {"baz": "AA=="},
                 "images": {"foobarbaz": "AA=="},
+                "tempLib": {"foofoo": "barbar"},
             },
         ),
     ],
@@ -517,11 +525,17 @@ def test_unstructure_lazy_font(ufo_UbuTestData: Font) -> None:
 
 @pytest.mark.parametrize("forbid_extra_keys", [True, False])
 def test_structure_forbid_extra_keys(forbid_extra_keys: bool) -> None:
-    conv = cattr.GenConverter(forbid_extra_keys=forbid_extra_keys)
+    conv = cattrs.Converter(
+        forbid_extra_keys=forbid_extra_keys,
+        detailed_validation=False,
+    )
     register_hooks(conv)
     data = {"name": "a", "foo": "bar"}
     if forbid_extra_keys:
-        with pytest.raises(Exception, match="Extra fields in constructor for .*: foo"):
+        with pytest.raises(
+            cattrs.errors.ForbiddenExtraKeysError,
+            match="Extra fields in constructor for .*: foo",
+        ):
             conv.structure(data, Glyph)
     else:
         assert conv.structure(data, Glyph) == Glyph(name="a")
@@ -566,6 +580,7 @@ def test_structure_forbid_extra_keys(forbid_extra_keys: bool) -> None:
                 "components": [],
                 "contours": [],
                 "guidelines": [],
+                "tempLib": {},
             },
             id="False-Glyph",
         ),
@@ -573,7 +588,13 @@ def test_structure_forbid_extra_keys(forbid_extra_keys: bool) -> None:
         pytest.param(
             False,
             Layer(),
-            {"name": "public.default", "default": True, "glyphs": {}, "lib": {}},
+            {
+                "name": "public.default",
+                "default": True,
+                "glyphs": {},
+                "lib": {},
+                "tempLib": {},
+            },
             id="False-Layer",
         ),
         pytest.param(
@@ -590,16 +611,23 @@ def test_structure_forbid_extra_keys(forbid_extra_keys: bool) -> None:
                 "info": {},
                 "kerning": {},
                 "layers": [
-                    {"default": True, "glyphs": {}, "lib": {}, "name": "public.default"}
+                    {
+                        "default": True,
+                        "glyphs": {},
+                        "lib": {},
+                        "name": "public.default",
+                        "tempLib": {},
+                    }
                 ],
                 "lib": {},
+                "tempLib": {},
             },
             id="False-Font",
         ),
     ],
 )
 def test_omit_if_default(obj: Any, expected: Any, omit_if_default: bool) -> None:
-    conv = cattr.GenConverter(omit_if_default=omit_if_default)
+    conv = cattrs.Converter(omit_if_default=omit_if_default)
     register_hooks(conv)
     assert conv.unstructure(obj) == expected
 
@@ -653,7 +681,7 @@ def test_omit_if_default(obj: Any, expected: Any, omit_if_default: bool) -> None
     ],
 )
 def test_allow_bytes(obj: Any, expected: Any, allow_bytes: bool) -> None:
-    conv = cattr.GenConverter()
+    conv = cattrs.Converter()
     register_hooks(conv, allow_bytes=allow_bytes)
 
     assert conv.unstructure(obj) == expected
@@ -661,7 +689,7 @@ def test_allow_bytes(obj: Any, expected: Any, allow_bytes: bool) -> None:
 
 
 def test_custom_type_overrides() -> None:
-    conv = cattr.GenConverter(type_overrides={Image: cattr.override(omit=True)})
+    conv = cattrs.Converter(type_overrides={Image: cattrs.override(omit=True)})
     register_hooks(conv)
 
     # check that Glyph.image attribute (of type Image) is omitted
@@ -674,6 +702,7 @@ def test_custom_type_overrides() -> None:
         "components": [],
         "contours": [],
         "guidelines": [],
+        "tempLib": {},
     }
 
 
